import React from 'react'
import {
  FaRegListAlt as LogIcon,
  FaSun as SunIcon,
  FaMoon as MoonIcon,
  FaRegSmile as HelpIcon
} from 'react-icons/fa'
// import { MdHelpOutline as HelpIcon } from 'react-icons/md'
import {
  Box,
  Menu,
  MenuButton,
  MenuList,
  MenuItem,
  Modal,
  ModalOverlay,
  ModalContent,
  ModalHeader,
  ModalFooter,
  ModalBody,
  Button,
  ModalCloseButton,
  Flex,
  Heading,
  IconButton,
  useColorMode,
  useDisclosure
} from '@chakra-ui/react'

export default function Header (props) {
  const { colorMode, toggleColorMode } = useColorMode()
  const bg = { light: 'white', dark: 'gray.800' }
  return (
    <>
      <Box h='2rem' />
      <Box
        pos='fixed'
        as='header'
        top='0'
        zIndex='4'
        bg={bg[colorMode]}
        left='0'
        right='0'
        borderBottomWidth='1px'
        width='full'
        height='2rem'
        {...props}
      >
        <Flex size='100%' px='4' align='center'>
          <Heading
            fontSize='md'
            letterSpacing='wide'
            mr={2}
            textTransform='uppercase'
            display='flex'
            lineHeight='2rem'
            height='2rem'
          >
        Sonar
          </Heading>

          <Flex flex='1' />

          <HelpMenu />
          <LogButton />
          <HeaderIconButton
            aria-label={`Switch to ${
            colorMode === 'light' ? 'dark' : 'light'
            } mode`}
            onClick={toggleColorMode}
            icon={colorMode === 'light' ? <MoonIcon /> : <SunIcon />}
          />
        </Flex>
      </Box>
    </>
  )
}

const headerButtonProps = {
  variant: 'ghost',
  color: 'current',
  // ml: '2',
  borderLeftWidth: '1px',
  borderLeftColor: 'gray.200',
  fontSize: 'md',
  height: '2rem',
  borderRadius: '0',
  transition: 'none',
}

const HeaderIconButton = React.forwardRef((props, ref) => {
  return (
    <IconButton
      {...headerButtonProps}
      ref={ref}
      {...props}
    />
  )
})

const HeaderButton = React.forwardRef((props, ref) => {
  return (
    <Button
      {...headerButtonProps}
      ref={ref}
      {...props}
    />
  )
})

function HelpMenu (props) {
  return (
    <Menu>
      <MenuButton
        as={HeaderButton}
        leftIcon={<HelpIcon />}
      >
        Docs
      </MenuButton>
      <MenuList>
        <MenuItem as='a' href='/api-docs-client' target='_blank'>
          Javascript API docs
        </MenuItem>
        <MenuItem as='a' href='/api-docs' target='_blank'>
          HTTP API docs
        </MenuItem>
      </MenuList>
    </Menu>
  )
}

function LogButton (props) {
  const { isOpen, onOpen, onClose } = useDisclosure()

  return (
    <>
      <HeaderIconButton
        aria-label='Show log'
        onClick={onOpen}
        icon={<LogIcon />}
        {...props}
      />
      <LogModal isOpen={isOpen} onClose={onClose} />
    </>
  )
}

function LogModal (props) {
  const { isOpen, onClose } = props
  return (
    <Modal isOpen={isOpen} onClose={onClose} scrollBehavior='inside'>
      <ModalOverlay />
      <ModalContent>
        <ModalHeader>Log</ModalHeader>
        <ModalCloseButton />
        <ModalBody>
          Log
        </ModalBody>

        <ModalFooter>
          <Button mr={3} onClick={onClose}>
              Close
          </Button>
        </ModalFooter>
      </ModalContent>
    </Modal>
  )
}
